@@ -43,6 +43,7 @@ OC.L10N.register(
     "Pending" : "Pendiente",
     "Error" : "Error",
     "Blocked" : "Bloqueado",
+    "Never" : "Nunca",
     "Language" : "Idioma",
     "Country" : "País",
     "Status" : "Estatus",
@@ -56,8 +57,8 @@ OC.L10N.register(
     "Checking …" : "Verificando ...",
     "Confirm" : "Confirmar",
     "Reset" : "Restablecer",
-    "Back" : "Atrás",
     "Cancel" : "Cancelar",
+    "Back" : "Atrás",
     "Calendar" : "Calendario",
     "Attendees" : "Asistentes",
     "Save" : "Guardar",
@@ -95,12 +96,10 @@ OC.L10N.register(
     "Upload" : "Cargar",
     "Files" : "Archivos",
     "Reply" : "Responder",
+    "More actions" : "Más acciones",
     "Translate" : "Traducir",
     "Dismiss" : "Descartar",
     "Contact" : "Contacto",
-    "Today" : "Hoy",
-    "Yesterday" : "Ayer",
-    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
     "Create new poll" : "Crear nueva encuesta",
     "Send" : "Enviar",
     "Create poll" : "Crear encuesta",
@@ -114,16 +113,10 @@ OC.L10N.register(
     "Chat" : "Chat",
     "Details" : "Detalles",
     "Privacy" : "Privacidad",
-    "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
-    "More actions" : "Más acciones",
-    "Default" : "Predeterminado",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
-    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
@@ -137,6 +130,7 @@ OC.L10N.register(
     "Polls" : "Encuestas",
     "Audio" : "Audio",
     "Other" : "Otro",
+    "Default" : "Predeterminado",
     "Group" : "Grupo",
     "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
@@ -149,6 +143,12 @@ OC.L10N.register(
     "iOS app" : "Aplicación iOS",
     "__language_name__" : "Español (Nicaragua)",
     "Tasks" : "Tareas",
-    "Close" : "Cerrar"
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
+    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
