@@ -377,6 +377,7 @@ OC.L10N.register(
     "Blocked" : "נחסם",
     "Active" : "פעיל",
     "Expired" : "פג",
+    "Never" : "מעולם לא",
     "Language" : "שפה",
     "Country" : "מדינה",
     "Status" : "מצב",
@@ -400,8 +401,8 @@ OC.L10N.register(
     "Checking …" : "מתבצעת בדיקה…",
     "Confirm" : "אימות",
     "Reset" : "איפוס",
-    "Back" : "חזרה",
     "Cancel" : "ביטול",
+    "Back" : "חזרה",
     "Loading …" : "בטעינה…",
     "From" : "מאת",
     "To" : "אל",
@@ -411,12 +412,15 @@ OC.L10N.register(
     "Search participants" : "חיפוש משתתפים",
     "No results" : "אין תוצאות",
     "Done" : "הסתיים",
+    "Speaker view" : "תצוגת דובר",
+    "Grid view" : "תצוגת טבלה",
     "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
     "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
     "Copy link" : "העתקת קישור",
     "Mute audio" : "השתקת שמע",
+    "None" : "אין",
     "Disable video" : "השבתת וידאו",
     "Enable video" : "הפעלת וידאו",
     "You" : "אני",
@@ -466,7 +470,6 @@ OC.L10N.register(
     "Groups" : "קבוצות",
     "Other sources" : "מקורות אחרים",
     "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
-    "None" : "אין",
     "Test" : "בדיקה",
     "Devices" : "מכשירים",
     "No audio" : "אין שמע",
@@ -475,17 +478,14 @@ OC.L10N.register(
     "Invalid path selected" : "הנתיב שנבחר שגוי",
     "Upload" : "העלאה",
     "Files" : "קבצים",
-    "Message sent" : "הודעה נשלחה",
-    "Deleting message" : "ההודעה נמחקה",
     "Reply" : "תגובה",
+    "More actions" : "פעולות נוספות",
     "Go to file" : "מעבר לקובץ",
     "Translate" : "תרגום",
     "Dismiss" : "התעלמות",
+    "Message sent" : "הודעה נשלחה",
+    "Deleting message" : "ההודעה נמחקה",
     "Contact" : "איש/אשת קשר",
-    "Today" : "היום",
-    "Yesterday" : "מחר",
-    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "אין הודעות",
     "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
     "Add participants" : "הוספת משתתפים",
@@ -522,29 +522,23 @@ OC.L10N.register(
     "Link to a conversation" : "קישור לדיון",
     "Select conversation" : "בחירת דיון",
     "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
-    "Attachments folder" : "תיקיית הקבצים המצורפים",
-    "Appearance" : "מראה",
+    "Notification settings" : "הגדרות התראה",
     "Privacy" : "פרטיות",
-    "Performance" : "ביצועים",
-    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Attachments folder" : "תיקיית הקבצים המצורפים",
     "Search" : "חיפוש",
     "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
     "Start call" : "התחלת שיחה",
     "Screensharing options" : "אפשרויות שיתוף מסך",
     "Enable screensharing" : "הפעלת שיתוף מסך",
     "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
-    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
     "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
     "Show your screen" : "הצגת המסך שלך",
     "Stop screensharing" : "הפסקת שיתוף המסך",
-    "Speaker view" : "תצוגת דובר",
-    "Grid view" : "תצוגת טבלה",
     "Mute others" : "השתקה של אחרים",
     "Keep" : "שימור",
     "Select a region" : "נא לבחור איזור",
     "Submit" : "שליחה",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "הודעה ללא אזכור",
     "Mention myself" : "אזכור עצמי",
     "The conversation does not exist" : "הדיון לא קיים",
@@ -587,13 +581,13 @@ OC.L10N.register(
     "Locations" : "מיקומים",
     "Audio" : "שמע",
     "Other" : "אחר",
+    "Default" : "בררת מחדל",
     "Group" : "קבוצה",
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
     "Please reload the page." : "יש להעלות מחדש דף זה.",
     "Do not disturb" : "לא להפריע",
     "Away" : "לא פה",
-    "Default" : "בררת מחדל",
     "Speaker {number}" : "רמקול {number}",
     "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
     "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
@@ -608,9 +602,15 @@ OC.L10N.register(
     "Tasks" : "משימות",
     "Notes" : "פתקים",
     "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
-    "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
-    "Copy conversation link" : "העתקת קישור דיון",
-    "Close" : "סגירה",
-    "Choose devices" : "בחירת התקנים"
+    "Today" : "היום",
+    "Yesterday" : "מחר",
+    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
+    "Choose devices" : "בחירת התקנים",
+    "Appearance" : "מראה",
+    "Performance" : "ביצועים",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
+    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך."
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
