@@ -393,8 +393,9 @@ OC.L10N.register(
     "OK" : "Labi",
     "Confirm" : "Apstiprināt",
     "Reset" : "Atiestatīt",
-    "Back" : "Atpakaļ",
     "Cancel" : "Atcelt",
+    "Back" : "Atpakaļ",
+    "Now" : "Tagad",
     "Loading …" : "Ielādē…",
     "From" : "No",
     "To" : "Līdz",
@@ -431,8 +432,8 @@ OC.L10N.register(
     "Personal" : "Personīgs",
     "Setup overview" : "Uzstādīšanas pārskats",
     "Leave conversation" : "Atstāt sarunu",
-    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Tiklīdz saruna ir pamesta, lai pievienotos slēgtai sarunai, ir nepieciešams uzaicinājums. Atvērtai sarunai var jebkurā brīdī pievienoties no jauna.",
     "Delete conversation" : "Izdzēst sarunu",
+    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Tiklīdz saruna ir pamesta, lai pievienotos slēgtai sarunai, ir nepieciešams uzaicinājums. Atvērtai sarunai var jebkurā brīdī pievienoties no jauna.",
     "_%n hour_::_%n hours_" : ["%n stundu","%n stunda","%n stundas"],
     "Password protection" : "Password protection",
     "Open conversation" : "Atvērt sarunu",
@@ -440,7 +441,9 @@ OC.L10N.register(
     "Delete" : "Izdzēst",
     "Notifications" : "Paziņojumi",
     "Join" : "Pievienoties",
+    "Hello, {displayName}" : "Sveiciens, {displayName}!",
     "Create and copy link" : "Izveidot saiti un ievietot starpliktuvē",
+    "Open calendar" : "Atvērt kalendāru",
     "Log in" : "Pieteikties",
     "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
@@ -484,6 +487,7 @@ OC.L10N.register(
     "Add teams" : "Pievienot komandas",
     "Searching …" : "Meklē...",
     "Participants" : "Dalībnieki",
+    "Open chat" : "Atvērt tērzēšanu",
     "Chat" : "Tērzēt",
     "Details" : "Informācija",
     "From User" : "No lietotāja",
@@ -493,9 +497,8 @@ OC.L10N.register(
     "Select conversation" : "Izvēlēties sarunu",
     "Error while setting read status privacy" : "Kļūda lasīšanas stāvokļa privātuma iestatīšanas laikā",
     "Error while setting typing status privacy" : "Kļūda rakstīšanas stāvokļa privātuma iestatīšanas laikā",
-    "Appearance" : "Izskats",
+    "Notification settings" : "Paziņojumu iestatījumi",
     "Privacy" : "Privātums",
-    "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Search" : "Meklēt",
     "Start call" : "Sākt zvanu",
     "All tasks done!" : "Visi uzdevumi paveikti.",
@@ -531,6 +534,7 @@ OC.L10N.register(
     "Show all polls" : "Parādīt visas aptaujas",
     "Default" : "Noklusējuma",
     "Group" : "Grupa",
+    "Team" : "Komanda",
     "You and {user0} left the call" : "Tu un {user0} pametāt zvanu",
     "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
     "Error while sharing file" : "Kļūda datnes kopīgošanā",
@@ -556,11 +560,11 @@ OC.L10N.register(
     "You were invited to a conversation." : "Tu uzaicinājāt uz sarunu.",
     "Click the button below to join." : "Jāklikšķina uz zemāk esošās pogas, lai pievienotos.",
     "Join »%s«" : "Pievienoties »%s«",
-    "{user} invited you to a private conversation" : "{user} uzaicināja Tevi uz privātu sarunu",
     "Today" : "Šodien",
     "Yesterday" : "Vakar",
     "_%n day ago_::_%n days ago_" : ["pirms %n dienām","pirms %n dienas","pirms %n dienām"],
-    "Close" : "Aizvērt",
+    "Appearance" : "Izskats",
+    "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
     "Screensharing extension is required to share your screen." : "Ir nepieciešams ekrāna kopīgošanas paplašinājums, lai kopīgotu savu ekrānu.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome, lai kopīgotu savu ekrānu."
