@@ -161,6 +161,7 @@ OC.L10N.register(
     "Dial-in information" : "Информации",
     "Meeting ID" : "ID на средба",
     "Your PIN" : "Вашиот ПИН",
+    "Talk conversation for event" : "Talk разговор за настанот",
     "Password request: %s" : "Барање за лозинка: %s",
     "Private conversation" : "Приватен разговор",
     "Deleted user (%s)" : "Избришан корисник (%s)",
@@ -577,8 +578,8 @@ OC.L10N.register(
     "Confirm" : "Потврди",
     "Reset" : "Ресетирање",
     "Room {roomNumber}" : "Соба {roomNumber}",
-    "Back" : "Назад",
     "Cancel" : "Откажи",
+    "Back" : "Назад",
     "Add participant \"{user}\"" : "Додади учесник \"{user}\"",
     "Now" : "Сега",
     "Loading …" : "Се вчитува…",
@@ -650,15 +651,15 @@ OC.L10N.register(
     "Basic Info" : "Основни информации",
     "Personal" : "Лично",
     "Danger zone" : "Опасна зона",
-    "Do you really want to delete \"{displayName}\"?" : "Дали навистина сакате да го избришете \"{displayName}\"?",
-    "Be careful, these actions cannot be undone." : "Бидете внимателни, овие дејства не можат да повратат.",
     "Leave conversation" : "Напушти разговор",
-    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Откако ќе излезете од разговорот, за повторно да се придружите на затворен разговор, потребна е покана. На отворен разговор може повторно да се придружите во секое време.",
     "Delete conversation" : "Избриши разговор",
+    "Do you really want to delete \"{displayName}\"?" : "Дали навистина сакате да го избришете \"{displayName}\"?",
+    "Delete all chat messages" : "Избришете ги сите пораки од разгоровот",
+    "Be careful, these actions cannot be undone." : "Бидете внимателни, овие дејства не можат да повратат.",
+    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Откако ќе излезете од разговорот, за повторно да се придружите на затворен разговор, потребна е покана. На отворен разговор може повторно да се придружите во секое време.",
     "Permanently delete this conversation." : "Трајно избришете го овој разговор",
     "Delete chat messages" : "Избришете ги пораките од разгоровот",
     "Permanently delete all the messages in this conversation." : "Трајно избришете ги сите пораки во овој разговор.",
-    "Delete all chat messages" : "Избришете ги сите пораки од разгоровот",
     "_%n hour_::_%n hours_" : ["1 час","%n часа"],
     "_%n day_::_%n days_" : ["1 ден","%n дена"],
     "_%n week_::_%n weeks_" : ["1 недела","%n недели"],
@@ -731,6 +732,7 @@ OC.L10N.register(
     "A reminder was successfully set at {datetime}" : "Успешно е поставен потсетник во {datetime}",
     "Error occurred when creating a reminder" : "Настана грешка при обид за поставување потсетник",
     "Reply" : "Одговор",
+    "More actions" : "Повеќе акции",
     "Set reminder" : "Постави потсетник",
     "Edit message" : "Уреди порака",
     "Copy message link" : "Копирај линк на пораката",
@@ -862,7 +864,6 @@ OC.L10N.register(
     "Select conversation" : "Избери разговор",
     "Edit display name" : "Иреди име",
     "Save name" : "Зачувај име",
-    "Choose the folder in which attachments should be saved." : "Изберете ја папката во која треба да се зачуваат прилозите.",
     "Select location for attachments" : "Избери локација за прилози",
     "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
     "Your privacy setting has been saved" : "Вашите поставки за приватност се зачувани",
@@ -870,27 +871,19 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Неуспешно зачувување на параметрите за звуци",
     "Sounds setting saved" : "Параматрите за звуци се зачувани",
     "Error while saving sounds setting" : "Грешка при зачувување на параметрите за звуци",
-    "Attachments folder" : "Папка со прилози",
-    "Appearance" : "Изглед",
-    "Privacy" : "Приватност",
-    "Share my read-status and show the read-status of others" : "Сподели го мојот статус на читање и прикажете го статусот на читање на другите",
-    "Sounds" : "Звуци",
     "Play sounds when participants join or leave a call" : "Репродуцирајте звуци кога учесниците се придружуваат или оставаат повик",
-    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Звуците за чет и известувања за повици може да се прилагодат во личните поставки.",
-    "Performance" : "Перформанси",
-    "Keyboard shortcuts" : "Кратенки преку тастатура",
-    "Speed up your Talk experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
+    "Notification settings" : "Параметри за известување",
+    "Privacy" : "Приватност",
+    "Attachments folder" : "Папка со прилози",
+    "Toggle full screen" : "Вклучи на цел екран",
+    "Search" : "Барај",
     "Focus the chat input" : "Фокусирајте го курсорот на разговорот",
     "Unfocus the chat input to use shortcuts" : "Отстранаете го курсорот од разговорот за да користите кратенки преку тастатура",
-    "Fullscreen the chat or call" : "Цел екран на разговор или повик",
-    "Search" : "Барај",
     "Shortcuts while in a call" : "Кратенки за време на повик",
     "Camera on and off" : "Вклучување и исклучување на камерата",
     "Microphone on and off" : "Вклучување и исклучување на микрофонот",
-    "Space bar" : "Празно место",
-    "Push to talk or push to mute" : "Притисни за разговор или притисни за занемување",
     "Raise or lower hand" : "Крени или спушти рака",
-    "More actions" : "Повеќе акции",
+    "Push to talk or push to mute" : "Притисни за разговор или притисни за занемување",
     "Start call silently" : "Започни товок повик",
     "Start call" : "Повик",
     "You will be able to join the call only after a moderator starts it." : "Ќе може да се придружите на повикот само откако модераторот ќе го започне.",
@@ -923,7 +916,6 @@ OC.L10N.register(
     "Show your screen" : "Прикажи го вашиот екран",
     "Stop screensharing" : "Запри споделување на екран",
     "Mute others" : "Занеми ги останатите",
-    "Toggle full screen" : "Вклучи на цел екран",
     "Keep" : "Задржи",
     "Select a region" : "Изберете регион",
     "Submit" : "Испрати",
@@ -990,6 +982,7 @@ OC.L10N.register(
     "An error occurred while ending the poll" : "Настана грешка при затварање на анкетата",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Прелистувачот што го користите не е целосно поддржан. Користете ја најновата верзија на Mozilla Firefox, Microsoft Edge, Google Chrome, Opera или Apple Safari.",
     "Conversation link copied to clipboard" : "Линк до разговорот е копиран во клипборд",
+    "Error while parsing a PROPFIND error" : "Грешка при обработка на PROPFIND грешката",
     "Please reload the page." : "Превчитајте ја страницата.",
     "Do not disturb" : "Не вознемирувај",
     "Away" : "Далеку",
@@ -1019,7 +1012,17 @@ OC.L10N.register(
     "Today" : "Денес",
     "Yesterday" : "Вчера",
     "_%n day ago_::_%n days ago_" : ["пред %n ден","пред %n дена"],
+    "Choose the folder in which attachments should be saved." : "Изберете ја папката во која треба да се зачуваат прилозите.",
     "Choose devices" : "Избери уреди",
+    "Appearance" : "Изглед",
+    "Share my read-status and show the read-status of others" : "Сподели го мојот статус на читање и прикажете го статусот на читање на другите",
+    "Sounds" : "Звуци",
+    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Звуците за чет и известувања за повици може да се прилагодат во личните поставки.",
+    "Performance" : "Перформанси",
+    "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Speed up your Talk experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
+    "Fullscreen the chat or call" : "Цел екран на разговор или повик",
+    "Space bar" : "Празно место",
     "Sharing your screen only works with Firefox version 52 or newer." : "Споделување на екранот е поддржано со Firefox верзија 52 или понова.",
     "Screensharing extension is required to share your screen." : "Потребен е додаток за споделување на вашиот екран.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Користете друг прелистувач како Firefox или Chrome за да го споделите вашиот екран."
