@@ -22,6 +22,7 @@ class Command implements IEventListener {
 	public const RESPONSE_USER = 1;
 	public const RESPONSE_ALL = 2;
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!$event instanceof MessageParseEvent) {
 			return;
@@ -49,9 +50,9 @@ class Command implements IEventListener {
 		}
 
 		$participant = $message->getParticipant();
-		if ($data['visibility'] !== self::RESPONSE_ALL &&
-			$participant !== null &&
-			($participant->getAttendee()->getActorType() !== Attendee::ACTOR_USERS
+		if ($data['visibility'] !== self::RESPONSE_ALL
+			&& $participant !== null
+			&& ($participant->getAttendee()->getActorType() !== Attendee::ACTOR_USERS
 				|| $data['user'] !== $participant->getAttendee()->getActorId())) {
 			$message->setVisibility(false);
 			return;
