@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Command\Monitor;
@@ -30,14 +15,14 @@ use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Output\OutputInterface;
 
 class Calls extends Base {
-	protected IDBConnection $connection;
 
-	public function __construct(IDBConnection $connection) {
+	public function __construct(
+		protected IDBConnection $connection,
+	) {
 		parent::__construct();
-
-		$this->connection = $connection;
 	}
 
+	#[\Override]
 	protected function configure(): void {
 		parent::configure();
 
@@ -65,12 +50,12 @@ class Calls extends Base {
 		$data = [];
 		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
-			$key = (string) $row['token'];
+			$key = (string)$row['token'];
 			if ($input->getOption('output') === Base::OUTPUT_FORMAT_PLAIN) {
 				$key = '"' . $key . '"';
 			}
 
-			$data[$key] = (int) $row['num_attendees'];
+			$data[$key] = (int)$row['num_attendees'];
 		}
 		$result->closeCursor();
 
