@@ -30,6 +30,10 @@ class Config {
 	public const SIGNALING_EXTERNAL = 'external';
 	public const SIGNALING_CLUSTER_CONVERSATION = 'conversation_cluster';
 
+	public const EXPERIMENTAL_UPDATE_PARTICIPANTS = 1;
+	public const EXPERIMENTAL_RECOVER_SESSION = 2;
+	public const EXPERIMENTAL_CHAT_RELAY = 4;
+
 	public const SIGNALING_TICKET_V1 = 1;
 	public const SIGNALING_TICKET_V2 = 2;
 
@@ -40,6 +44,8 @@ class Config {
 	 */
 	public const USER_STATUS_INTEGRATION_LIMIT = 1000;
 
+	private const EXPERIMENT_CHAT_RELAY = 4;
+
 	/** @var array<string, bool> */
 	protected array $canEnableSIP = [];
 
@@ -768,6 +774,14 @@ class Config {
 		return $this->appConfig->getAppValueBool('inactivity_enable_lobby');
 	}
 
+	/**
+	 * @param self::EXPERIMENTAL_* $experiment
+	 */
+	public function hasExperiment(int $experiment): bool {
+		return $this->appConfig->getAppValueInt('experiments_users') & $experiment
+			|| $this->appConfig->getAppValueInt('experiments_guests') & $experiment;
+	}
+
 	public function isPasswordEnforced(): bool {
 		return $this->appConfig->getAppValueBool('force_passwords');
 	}
@@ -780,4 +794,17 @@ class Config {
 		// TODO Default value will be set to true, once all mobile clients support it.
 		return $this->appConfig->getAppValueBool('call_end_to_end_encryption');
 	}
+
+	public function isChatRelayEnabled(): bool {
+		$isEnabled
+			= (max(0, $this->appConfig->getAppValueInt('experiments_users'))
+				| max(0, $this->appConfig->getAppValueInt('experiments_guests'))
+			)
+			& self::EXPERIMENT_CHAT_RELAY;
+		return $isEnabled === self::EXPERIMENT_CHAT_RELAY;
+	}
+
+	public function getPlaySoundsDefaultForGuests(): bool {
+		return $this->appConfig->getAppValueBool('guests_play_sounds', true);
+	}
 }
