@@ -2,50 +2,27 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 namespace OCA\Talk\Migration;
 
-use Doctrine\DBAL\Platforms\PostgreSQL94Platform;
-use Doctrine\DBAL\Types\Types;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCP\DB\ISchemaWrapper;
 use OCP\DB\QueryBuilder\IQueryBuilder;
+use OCP\DB\Types;
 use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\Migration\IOutput;
 use OCP\Migration\SimpleMigrationStep;
 
 class Version2001Date20170707115443 extends SimpleMigrationStep {
-	protected IDBConnection $db;
-
-	protected IConfig $config;
 
 	public function __construct(
-		IDBConnection $db,
-		IConfig $config,
+		protected IDBConnection $db,
+		protected IConfig $config,
 	) {
-		$this->db = $db;
-		$this->config = $config;
 	}
 
 	/**
@@ -55,6 +32,7 @@ class Version2001Date20170707115443 extends SimpleMigrationStep {
 	 * @return null|ISchemaWrapper
 	 * @since 13.0.0
 	 */
+	#[\Override]
 	public function changeSchema(IOutput $output, \Closure $schemaClosure, array $options): ?ISchemaWrapper {
 		/** @var ISchemaWrapper $schema */
 		$schema = $schemaClosure();
@@ -77,6 +55,7 @@ class Version2001Date20170707115443 extends SimpleMigrationStep {
 	 * @param array $options
 	 * @since 13.0.0
 	 */
+	#[\Override]
 	public function postSchemaChange(IOutput $output, \Closure $schemaClosure, array $options): void {
 		if (version_compare($this->config->getAppValue('spreed', 'installed_version', '0.0.0'), '2.0.0', '<')) {
 			// Migrations only work after 2.0.0
@@ -88,9 +67,9 @@ class Version2001Date20170707115443 extends SimpleMigrationStep {
 		$query->selectAlias($query->createFunction('COUNT(*)'), 'num_rooms')
 			->from('spreedme_rooms');
 		$result = $query->executeQuery();
-		$return = (int) $result->fetch();
+		$return = (int)$result->fetch();
 		$result->closeCursor();
-		$numRooms = (int) $return['num_rooms'];
+		$numRooms = (int)$return['num_rooms'];
 
 		if ($numRooms === 0) {
 			return;
@@ -103,7 +82,7 @@ class Version2001Date20170707115443 extends SimpleMigrationStep {
 
 		$one2oneRooms = [];
 		while ($row = $result->fetch()) {
-			$one2oneRooms[] = (int) $row['id'];
+			$one2oneRooms[] = (int)$row['id'];
 		}
 		$result->closeCursor();
 
@@ -125,7 +104,7 @@ class Version2001Date20170707115443 extends SimpleMigrationStep {
 	protected function makeOne2OneParticipantsOwners(array $one2oneRooms): int {
 		$update = $this->db->getQueryBuilder();
 
-		if (!$this->db->getDatabasePlatform() instanceof PostgreSQL94Platform) {
+		if ($this->db->getDatabaseProvider() !== IDBConnection::PLATFORM_POSTGRES) {
 			$update->update('spreedme_room_participants')
 				->set('participantType', $update->createNamedParameter(Participant::OWNER))
 				->where($update->expr()->in('roomId', $update->createNamedParameter($one2oneRooms, IQueryBuilder::PARAM_INT_ARRAY)));
@@ -145,7 +124,7 @@ class Version2001Date20170707115443 extends SimpleMigrationStep {
 	protected function makeGroupParticipantsModerators(array $one2oneRooms): int {
 		$update = $this->db->getQueryBuilder();
 
-		if (!$this->db->getDatabasePlatform() instanceof PostgreSQL94Platform) {
+		if ($this->db->getDatabaseProvider() !== IDBConnection::PLATFORM_POSTGRES) {
 			$update->update('spreedme_room_participants')
 				->set('participantType', $update->createNamedParameter(Participant::MODERATOR))
 				->where($update->expr()->nonEmptyString('userId'));
